==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ColumnSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSortDescriptionDescription } from "./ColumnSortDescriptionDescription";
/**
 * @hidden
 */
var ColumnSortDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ColumnSortDescriptionDescriptionMetadata, _super);
    function ColumnSortDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSortDescriptionDescriptionMetadata.b = function (a) {
        if (ColumnSortDescriptionDescriptionMetadata.a == null) {
            ColumnSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSortDescriptionDescriptionMetadata.c(ColumnSortDescriptionDescriptionMetadata.a);
        }
        if (a.j(ColumnSortDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.y(ColumnSortDescriptionDescriptionMetadata.a);
    };
    ColumnSortDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("SortDirection", "ExportedType:string:ListSortDirection");
        a.item("SortDirection@names", "Ascending;Descending");
    };
    ColumnSortDescriptionDescriptionMetadata.d = function (a) {
        ColumnSortDescriptionDescriptionMetadata.b(a);
        a.aa("ColumnSortDescription", function () { return new ColumnSortDescriptionDescription(); });
        a.z("ColumnSortDescription", ColumnSortDescriptionDescriptionMetadata.a);
    };
    ColumnSortDescriptionDescriptionMetadata.$t = markType(ColumnSortDescriptionDescriptionMetadata, 'ColumnSortDescriptionDescriptionMetadata');
    ColumnSortDescriptionDescriptionMetadata.a = null;
    return ColumnSortDescriptionDescriptionMetadata;
}(Base));
export { ColumnSortDescriptionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ColumnSortDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnSortDescriptionDescription } from "./ColumnSortDescriptionDescription";
/**
 * @hidden
 */
var ColumnSortDescriptionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ColumnSortDescriptionDescriptionMetadata, _super);
    function ColumnSortDescriptionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ColumnSortDescriptionDescriptionMetadata.b = function (a) {
        if (ColumnSortDescriptionDescriptionMetadata.a == null) {
            ColumnSortDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ColumnSortDescriptionDescriptionMetadata.c(ColumnSortDescriptionDescriptionMetadata.a);
        }
        if (a.k(ColumnSortDescriptionDescriptionMetadata.a)) {
            return;
        }
        a.aa(ColumnSortDescriptionDescriptionMetadata.a);
    };
    ColumnSortDescriptionDescriptionMetadata.c = function (a) {
        a.item("Field", "String");
        a.item("SortDirection", "ExportedType:string:ListSortDirection");
        a.item("SortDirection@names", "Ascending;Descending");
    };
    ColumnSortDescriptionDescriptionMetadata.d = function (a) {
        ColumnSortDescriptionDescriptionMetadata.b(a);
        a.ac("ColumnSortDescription", function () { return new ColumnSortDescriptionDescription(); });
        a.ab("ColumnSortDescription", ColumnSortDescriptionDescriptionMetadata.a);
    };
    ColumnSortDescriptionDescriptionMetadata.$t = markType(ColumnSortDescriptionDescriptionMetadata, 'ColumnSortDescriptionDescriptionMetadata');
    ColumnSortDescriptionDescriptionMetadata.a = null;
    return ColumnSortDescriptionDescriptionMetadata;
}(Base));
export { ColumnSortDescriptionDescriptionMetadata };
